import sys

from hakisto import logger


def color():
    logger.file_handler.severity = sys.maxsize
    logger.set_severity(0)

    logger.trace("Trace")
    logger.debug("Debug")
    logger.verbose("Verbose")
    logger.info("Info")
    logger.success("Success")
    logger.warning("Warning")
    logger.error("Error")


def critical():
    s = "Hakisto"
    msg = f"Colors with {s} is easy!"  # noqa: F841
    logger.critical("A critical issue!")


def traceback():
    s = "Hakisto"
    msg = f"Colors with {s} is easy!"  # noqa: F841
    b = s[10]  # noqa: F841


if __name__ == '__main__':
    color()
    critical()
    traceback()


#  hakisto - logging reimagined
#
#  Copyright (C) 2024  Bernhard Radermacher
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.

from ._logger import Logger  # noqa: F401
from .colors import (
    BLACK,  # noqa: F401
    RED,  # noqa: F401
    GREEN,  # noqa: F401
    YELLOW,  # noqa: F401
    BLUE,  # noqa: F401
    MAGENTA,  # noqa: F401
    CYAN,  # noqa: F401
    WHITE,  # noqa: F401
    RESET,  # noqa: F401
    LIGHT_BLACK,  # noqa: F401
    LIGHT_RED,  # noqa: F401
    LIGHT_GREEN,  # noqa: F401
    LIGHT_YELLOW,  # noqa: F401
    LIGHT_BLUE,  # noqa: F401
    LIGHT_MAGENTA,  # noqa: F401
    LIGHT_CYAN,  # noqa: F401
    LIGHT_WHITE,  # noqa: F401
    colorize_string,  # noqa: F401
)
from .file_handler import FileHandler, rotate_file  # noqa: F401
from .handler import Identifier, Handler  # noqa: F401
from .indented_mixin import IndentedMixin  # noqa: F401
from .severity import (
    TRACE,  # noqa: F401
    DEBUG,  # noqa: F401
    VERBOSE,  # noqa: F401
    INFO,  # noqa: F401
    SUCCESS,  # noqa: F401
    WARNING,  # noqa: F401
    ERROR,  # noqa: F401
    CRITICAL,  # noqa: F401
    severities,  # noqa: F401
    severity_colors,  # noqa: F401
    light_severity_colors,  # noqa: F401
    dark_severity_colors,  # noqa: F401
)
from .single_line_mixin import SingleLineMixin  # noqa: F401
from .stderr_handler import StdErrHandler  # noqa: F401
from .stream import Stream, get_top_caller  # noqa: F401
from .subject import (
    Subject,  # noqa: F401
    SourceExtractLine,  # noqa: F401
    FrameInformation,  # noqa: F401
    TracebackRecord,  # noqa: F401
    get_frame_information,  # noqa: F401
    get_traceback_information,  # noqa: F401
    get_source_location,  # noqa: F401
)
from .topic import construct_topic, extract_topic  # noqa: F401
